==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/CapabilitiesObject.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.CapabilitiesCreateObject;
import com.okta.sdk.resource.model.CapabilitiesUpdateObject;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Defines the configurations for the USER_PROVISIONING feature
 */
@ApiModel(description = "Defines the configurations for the USER_PROVISIONING feature")
@JsonPropertyOrder({ CapabilitiesObject.JSON_PROPERTY_CREATE, CapabilitiesObject.JSON_PROPERTY_UPDATE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class CapabilitiesObject implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CREATE = "create";
    private CapabilitiesCreateObject create;

    public static final String JSON_PROPERTY_UPDATE = "update";
    private CapabilitiesUpdateObject update;

    public CapabilitiesObject() {
    }

    public CapabilitiesObject create(CapabilitiesCreateObject create) {

        this.create = create;
        return this;
    }

    /**
     * Get create
     *
     * @return create
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CREATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public CapabilitiesCreateObject getCreate() {
        return create;
    }

    @JsonProperty(JSON_PROPERTY_CREATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCreate(CapabilitiesCreateObject create) {
        this.create = create;
    }

    public CapabilitiesObject update(CapabilitiesUpdateObject update) {

        this.update = update;
        return this;
    }

    /**
     * Get update
     *
     * @return update
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_UPDATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public CapabilitiesUpdateObject getUpdate() {
        return update;
    }

    @JsonProperty(JSON_PROPERTY_UPDATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUpdate(CapabilitiesUpdateObject update) {
        this.update = update;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        CapabilitiesObject capabilitiesObject = (CapabilitiesObject) o;
        return Objects.equals(this.create, capabilitiesObject.create)
                && Objects.equals(this.update, capabilitiesObject.update);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(create, update);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class CapabilitiesObject {\n");
        sb.append("    create: ").append(toIndentedString(create)).append("\n");
        sb.append("    update: ").append(toIndentedString(update)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/CapabilitiesObject.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.CapabilitiesCreateObject;
import com.okta.sdk.resource.model.CapabilitiesUpdateObject;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * Defines the configurations for the USER_PROVISIONING feature
 */
@ApiModel(description = "Defines the configurations for the USER_PROVISIONING feature")
@JsonPropertyOrder({ CapabilitiesObject.JSON_PROPERTY_CREATE, CapabilitiesObject.JSON_PROPERTY_UPDATE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class CapabilitiesObject implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_CREATE = "create";
    private CapabilitiesCreateObject create;

    public static final String JSON_PROPERTY_UPDATE = "update";
    private CapabilitiesUpdateObject update;

    public CapabilitiesObject() {
    }

    public CapabilitiesObject create(CapabilitiesCreateObject create) {

        this.create = create;
        return this;
    }

    /**
     * Get create
     *
     * @return create
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CREATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public CapabilitiesCreateObject getCreate() {
        return create;
    }

    @JsonProperty(JSON_PROPERTY_CREATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setCreate(CapabilitiesCreateObject create) {
        this.create = create;
    }

    public CapabilitiesObject update(CapabilitiesUpdateObject update) {

        this.update = update;
        return this;
    }

    /**
     * Get update
     *
     * @return update
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_UPDATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public CapabilitiesUpdateObject getUpdate() {
        return update;
    }

    @JsonProperty(JSON_PROPERTY_UPDATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUpdate(CapabilitiesUpdateObject update) {
        this.update = update;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        CapabilitiesObject capabilitiesObject = (CapabilitiesObject) o;
        return Objects.equals(this.create, capabilitiesObject.create)
                && Objects.equals(this.update, capabilitiesObject.update);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(create, update);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class CapabilitiesObject {\n");
        sb.append("    create: ").append(toIndentedString(create)).append("\n");
        sb.append("    update: ").append(toIndentedString(update)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
